from setuptools import setup

setup(
    name='mission',
    version='0.0.1',
    description='Simple threadpool',
    author='YogaPan',
    author_email='godhand1234567@gmail.com',
    packages=['mission'],
    install_requires=[],
    url='https://github.com/yogapan/mission',
    download_url=''
)
